@@ -9,7 +9,7 @@ class TerminalVelocity(DerivedAttribute):
         dependencies = [self.radius]
         super().__init__(builder, name='terminal velocity', dependencies=dependencies)
 
-        self.approximation = Interpolation(builder.core)
+        self.approximation = Interpolation(builder.particulator)
 
     def recalculate(self):
         self.approximation(self.data, self.radius.get())
